"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.encodeMdLink = encodeMdLink;
exports.getTrigger = getTrigger;
exports.isGrapeUrl = isGrapeUrl;
exports.getOptions = getOptions;

var _parseUrl = _interopRequireDefault(require("../parse-url"));

var _javascriptProtocol = _interopRequireDefault(require("../javascript-protocol"));

var _constants = require("./constants");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr && (typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]); if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

/**
 * Escape markdown link target or name.
 */
function encodeMdLink(link) {
  // eslint-disable-next-line no-useless-escape
  var regExp = /[\[\]()\s]/g;
  return link.replace(regExp, function (c) {
    return "%".concat(c.charCodeAt(0).toString(16));
  });
}
/**
 * Get trigger string based on object type
 */


function getTrigger(type) {
  switch (type) {
    case 'user':
    case 'room':
      return '@';

    default:
      return '#';
  }
}
/**
 * Returns true if passed url uses grapes own protocol.
 */


function isGrapeUrl(url) {
  return (0, _parseUrl["default"])(url).protocol === _constants.grapeProtocol;
}
/**
 * Create an options object from text and grape url which will be accepted by
 * the classes.
 */


function getOptions(text, grapeUrl) {
  if (!isGrapeUrl(grapeUrl)) return false;

  var _grapeUrl$slice$split = grapeUrl.slice(5).split('|'),
      _grapeUrl$slice$split2 = _slicedToArray(_grapeUrl$slice$split, 4),
      service = _grapeUrl$slice$split2[0],
      type = _grapeUrl$slice$split2[1],
      id = _grapeUrl$slice$split2[2],
      url = _grapeUrl$slice$split2[3];

  var validUrl = url; // Checking javascript:// is an XSS protection.

  if (!url || (0, _javascriptProtocol["default"])(url)) validUrl = '';
  var nameWithoutTrigger; // 'text' can be empty because of broken jira integration
  // https://jira.ubergrape.com/browse/GRAPE-14163

  if (text) {
    nameWithoutTrigger = text[0] === getTrigger(type) ? text.substr(1) : text;
  } else {
    nameWithoutTrigger = '';
  }

  return {
    id: id,
    service: service,
    type: type,
    url: validUrl,
    name: text,
    slug: validUrl.replace('/chat/', ''),
    nameWithoutTrigger: nameWithoutTrigger
  };
}