"use strict";

var _expect = _interopRequireDefault(require("expect.js"));

var _findMatches = _interopRequireDefault(require("../findMatches"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

// eslint-disable-next-line import/no-extraneous-dependencies
describe('findMatches()', function () {
  it('should return single match', function () {
    var matches = (0, _findMatches["default"])('a', 'a');
    (0, _expect["default"])(matches.length).to.be(1);
    (0, _expect["default"])(matches[0].text).to.be('a');
    (0, _expect["default"])(matches[0].found).to.be.ok();
  });
  it('should return match with special chars', function () {
    var matches = (0, _findMatches["default"])('+', '+');
    (0, _expect["default"])(matches.length).to.be(1);
    (0, _expect["default"])(matches[0].text).to.be('+');
    (0, _expect["default"])(matches[0].found).to.be.ok();
  });
  it('should return case insensitive match', function () {
    var matches = (0, _findMatches["default"])('a', 'A');
    (0, _expect["default"])(matches.length).to.be(1);
    (0, _expect["default"])(matches[0].text).to.be('a');
    (0, _expect["default"])(matches[0].found).to.be.ok();
  });
  it('should return word only match (0)', function () {
    var matches = (0, _findMatches["default"])('ab', 'a');
    (0, _expect["default"])(matches.length).to.be(1);
    (0, _expect["default"])(matches[0].text).to.be('ab');
    (0, _expect["default"])(matches[0].found).to.not.be.ok();
  });
  it('should return word only match (1)', function () {
    var matches = (0, _findMatches["default"])('ba', 'a');
    (0, _expect["default"])(matches.length).to.be(1);
    (0, _expect["default"])(matches[0].text).to.be('ba');
    (0, _expect["default"])(matches[0].found).to.not.be.ok();
  });
  it('should return word only match (2)', function () {
    var matches = (0, _findMatches["default"])('a,', 'a');
    (0, _expect["default"])(matches.length).to.be(2);
    (0, _expect["default"])(matches[0].text).to.be('a');
    (0, _expect["default"])(matches[0].found).to.be.ok();
    (0, _expect["default"])(matches[1].text).to.be(',');
    (0, _expect["default"])(matches[1].found).to.not.be.ok();
  });
  it('should return word only match (3)', function () {
    var matches = (0, _findMatches["default"])(',a', 'a');
    (0, _expect["default"])(matches.length).to.be(2);
    (0, _expect["default"])(matches[0].text).to.be(',');
    (0, _expect["default"])(matches[0].found).to.not.be.ok();
    (0, _expect["default"])(matches[1].text).to.be('a');
    (0, _expect["default"])(matches[1].found).to.be.ok();
  });
  it('should return multi match', function () {
    var matches = (0, _findMatches["default"])('a a', 'a');
    (0, _expect["default"])(matches.length).to.be(3);
    (0, _expect["default"])(matches[0].text).to.be('a');
    (0, _expect["default"])(matches[0].found).to.be.ok();
    (0, _expect["default"])(matches[1].text).to.be(' ');
    (0, _expect["default"])(matches[1].found).to.not.be.ok();
    (0, _expect["default"])(matches[2].text).to.be('a');
    (0, _expect["default"])(matches[2].found).to.be.ok();
  });
  it('should use multi search', function () {
    var matches = (0, _findMatches["default"])('a b', ['a', 'b']);
    (0, _expect["default"])(matches.length).to.be(3);
    (0, _expect["default"])(matches[0].text).to.be('a');
    (0, _expect["default"])(matches[0].found).to.be.ok();
    (0, _expect["default"])(matches[1].text).to.be(' ');
    (0, _expect["default"])(matches[1].found).to.not.be.ok();
    (0, _expect["default"])(matches[2].text).to.be('b');
    (0, _expect["default"])(matches[2].found).to.be.ok();
  });
  it('shoud match word combination', function () {
    var matches = (0, _findMatches["default"])('a b c d', 'b c');
    (0, _expect["default"])(matches.length).to.be(3);
    (0, _expect["default"])(matches[0].text).to.be('a ');
    (0, _expect["default"])(matches[0].found).to.not.be.ok();
    (0, _expect["default"])(matches[1].text).to.be('b c');
    (0, _expect["default"])(matches[1].found).to.be.ok();
    (0, _expect["default"])(matches[2].text).to.be(' d');
    (0, _expect["default"])(matches[2].found).to.not.be.ok();
  });
  it('shoud match multiple word combinations', function () {
    var matches = (0, _findMatches["default"])('a b c d e', ['b c', 'd e']);
    (0, _expect["default"])(matches.length).to.be(4);
    (0, _expect["default"])(matches[0].text).to.be('a ');
    (0, _expect["default"])(matches[0].found).to.not.be.ok();
    (0, _expect["default"])(matches[1].text).to.be('b c');
    (0, _expect["default"])(matches[1].found).to.be.ok();
    (0, _expect["default"])(matches[2].text).to.be(' ');
    (0, _expect["default"])(matches[2].found).to.not.be.ok();
    (0, _expect["default"])(matches[3].text).to.be('d e');
    (0, _expect["default"])(matches[3].found).to.be.ok();
  });
});