"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "openUrl", {
  enumerable: true,
  get: function get() {
    return _web.openUrl;
  }
});
Object.defineProperty(exports, "updateNotification", {
  enumerable: true,
  get: function get() {
    return _web.updateNotification;
  }
});
exports.isElectron = exports.setWebClientVersion = exports.onCallFinished = exports.onCallStarted = exports.removeBadge = exports.addBadge = exports.createNotification = void 0;

var _random = _interopRequireDefault(require("lodash/random"));

var _web = require("./web");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var createNotification = function createNotification(options) {
  var properties = options.properties,
      params = options.params,
      callbacks = options.callbacks; // Changing API for showNotification function, but old desktop clients should also be supported.
  // Please remove within some time. window.grapeAppVersion only exist for desktop client >= 3.0.0

  if (!window.grapeAppVersion) {
    // Handling notifications for old desktop client (< 3.0.0)
    window.grapeAppBridge.showNotification(properties, callbacks, {
      random: _random["default"],
      createWebNotification: _web.createNotification
    }, params);
    return;
  } // Handling notifications for new desktop client (>= 3.0.0)


  window.grapeAppBridge.showNotification({
    properties: properties,
    params: params,
    callbacks: callbacks,
    dependencies: {
      random: _random["default"],
      createWebNotification: _web.createNotification
    }
  });
  window.grapeAppBridge.bounceIcon();
};
/**
 * Electron implements the web api.
 */


exports.createNotification = createNotification;

/**
 * Add badge will:
 * - render the doc icon badge
 * - highlight OSX Tray
 * - highlight Windows Taskbar Icon
 */
var addBadge = function addBadge(text) {
  window.grapeAppBridge.addBadge(text);
};
/**
 * Remove badge will:
 * - remove the doc icon badge
 * - remove OSX Tray highlighting
 * - remove Windows Taskbar Icon highlighting
 */


exports.addBadge = addBadge;

var removeBadge = function removeBadge() {
  window.grapeAppBridge.removeBadge();
}; // Sends signal to Electron that call started


exports.removeBadge = removeBadge;

var onCallStarted = function onCallStarted() {
  // Backward compatibility, remove within sometime
  if (window.grapeAppBridge.onCallStarted) {
    window.grapeAppBridge.onCallStarted();
  }
}; // Sends signal to Electron that call finished


exports.onCallStarted = onCallStarted;

var onCallFinished = function onCallFinished() {
  // Backward compatibility, remove within sometime
  if (window.grapeAppBridge.onCallFinished) {
    window.grapeAppBridge.onCallFinished();
  }
};

exports.onCallFinished = onCallFinished;

var setWebClientVersion = function setWebClientVersion(version) {
  // Backward compatibility, remove within sometime
  if (window.grapeAppBridge.setWebClientVersion) {
    window.grapeAppBridge.setWebClientVersion(version);
  }
}; // window.grapeAppBridge comes from preload script in desktop app


exports.setWebClientVersion = setWebClientVersion;
var isElectron = window.grapeAppBridge;
exports.isElectron = isElectron;