"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _reactRouterDom = require("react-router-dom");

var _router = require("../../router");

var _parseUrl2 = _interopRequireDefault(require("../../parse-url"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var onForeign = function onForeign(pathOrUrl, _ref) {
  var onExternal = _ref.onExternal;
  onExternal(pathOrUrl, '_blank');
};

var onSso = function onSso(pathOrUrl, options) {
  var onRedirect = options.onRedirect,
      onExternal = options.onExternal,
      mode = options.mode;

  if (mode === 'embedded') {
    onRedirect(pathOrUrl);
    return;
  }

  onExternal(pathOrUrl, '_blank');
};

var onLogin = function onLogin(pathOrUrl, options) {
  var serviceUrl = options.serviceUrl,
      pathname = options.pathname,
      onRedirect = options.onRedirect;
  onRedirect("".concat(serviceUrl).concat(pathname));
};

var onLogout = function onLogout(pathOrUrl, options) {
  var onSilentChange = options.onSilentChange,
      onRedirect = options.onRedirect,
      mode = options.mode,
      pathname = options.pathname,
      serviceUrl = options.serviceUrl;

  if (mode === 'embedded') {
    onSilentChange(pathname, {});
    return;
  }

  onRedirect("".concat(serviceUrl).concat(pathname));
};

var onPm = function onPm(pathOrUrl, options) {
  var onExternal = options.onExternal,
      onRedirect = options.onRedirect,
      onSilentChange = options.onSilentChange,
      mode = options.mode,
      serviceUrl = options.serviceUrl,
      hostname = options.hostname,
      pathname = options.pathname,
      pmMatch = options.pmMatch;

  if (mode === 'embedded' || hostname && mode !== 'full') {
    onExternal("".concat(serviceUrl).concat(pathname), 'grape');
    return;
  }

  if (hostname && mode === 'full') {
    onRedirect("".concat(serviceUrl).concat(pathname));
    return;
  }

  onSilentChange(pathname, {
    mateId: pmMatch.params.mateId,
    type: 'pm'
  });
};

var onChannel = function onChannel(pathOrUrl, options) {
  var onExternal = options.onExternal,
      onSilentChange = options.onSilentChange,
      onUpdateRouter = options.onUpdateRouter,
      mode = options.mode,
      serviceUrl = options.serviceUrl,
      pathname = options.pathname,
      currChannel = options.currChannel,
      channelMatch = options.channelMatch;
  var _channelMatch$params = channelMatch.params,
      channelId = _channelMatch$params.channelId,
      messageId = _channelMatch$params.messageId;

  if (Number(channelId) === currChannel) {
    if (!messageId) return;
    onSilentChange(pathname, {
      channelId: Number(channelId),
      messageId: messageId,
      type: 'channel'
    });
    return;
  }

  if (mode === 'embedded') {
    onExternal("".concat(serviceUrl).concat(pathname), 'grape');
    return;
  }

  onUpdateRouter(pathname, 'push');
};

var onChatPath = function onChatPath(pathOrUrl, options) {
  var onUpdateRouter = options.onUpdateRouter,
      serviceUrl = options.serviceUrl,
      mode = options.mode,
      pathname = options.pathname,
      onExternal = options.onExternal;

  if (mode === 'embedded') {
    onExternal("".concat(serviceUrl).concat(pathname), 'grape');
    return;
  }

  onUpdateRouter(pathname, 'push');
};

var onChat = function onChat(pathOrUrl, options) {
  var pathname = options.pathname,
      hostname = options.hostname;
  var channelMatch = (0, _reactRouterDom.matchPath)(pathname, {
    path: _router.routes.channel
  });

  if (channelMatch) {
    onChannel(pathOrUrl, _objectSpread(_objectSpread({}, options), {}, {
      channelMatch: channelMatch
    }));
    return;
  }

  var pmMatch = (0, _reactRouterDom.matchPath)(pathname, {
    path: _router.routes.pm
  });

  if (pmMatch) {
    onPm(pathOrUrl, _objectSpread(_objectSpread({}, options), {}, {
      hostname: hostname,
      pmMatch: pmMatch
    }));
  }
};

var onRootAndFull = function onRootAndFull(pathOrUrl, options) {
  var onExternal = options.onExternal,
      onRedirect = options.onRedirect,
      mode = options.mode,
      pathname = options.pathname,
      serviceUrl = options.serviceUrl,
      search = options.search;

  if (mode === 'embedded') {
    onExternal("".concat(serviceUrl).concat(pathname).concat(search || ''), 'grape');
    return;
  }

  onRedirect("".concat(serviceUrl).concat(pathname).concat(search || ''));
};

var _default = function _default(pathOrUrl, options) {
  var loginPath = '/accounts/login';
  var logoutPath = '/accounts/logout';
  var ssoPath = '/sso/sso';
  var onExternal = options.onExternal,
      mode = options.mode,
      serviceUrl = options.serviceUrl;

  var _parseUrl = (0, _parseUrl2["default"])(pathOrUrl),
      pathname = _parseUrl.pathname,
      hostname = _parseUrl.hostname,
      search = _parseUrl.search;

  if (hostname && hostname !== (0, _parseUrl2["default"])(serviceUrl).hostname) {
    onForeign(pathOrUrl, options);
    return;
  }

  if (pathname === ssoPath) {
    onSso(pathOrUrl, _objectSpread({}, options));
    return;
  }

  if (pathname === loginPath) {
    onLogin(pathOrUrl, _objectSpread(_objectSpread({}, options), {}, {
      pathname: pathname
    }));
    return;
  }

  if (pathname === logoutPath) {
    onLogout(pathOrUrl, _objectSpread(_objectSpread({}, options), {}, {
      pathname: pathname
    }));
    return;
  }

  if (pathname.substr(0, 5) === '/chat') {
    if (pathname === '/chat') {
      onChatPath(pathOrUrl, _objectSpread(_objectSpread({}, options), {}, {
        hostname: hostname,
        pathname: pathname
      }));
    }

    onChat(pathOrUrl, _objectSpread(_objectSpread({}, options), {}, {
      hostname: hostname,
      pathname: pathname
    }));
    return;
  }

  if (pathname === '/' || mode === 'full') {
    onRootAndFull(pathOrUrl, _objectSpread(_objectSpread({}, options), {}, {
      pathname: pathname,
      search: search
    }));
    return;
  }

  onExternal("".concat(serviceUrl).concat(pathname).concat(search || ''), 'grape');
};

exports["default"] = _default;