"use strict";

var _expect = _interopRequireDefault(require("expect.js"));

var _ = _interopRequireDefault(require(".."));

var _utils = require("./utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

describe('goTo with url in electron mode', function () {
  it("shouldn't call any callbacks if URL has no messageId and channel is current", function () {
    var _callbacks = (0, _utils.callbacks)(),
        map = _callbacks.map,
        called = _callbacks.called,
        args = _callbacks.args;

    (0, _["default"])('https://grape.io/chat/channel/6009', _objectSpread({
      currChannel: 6009,
      serviceUrl: 'https://grape.io',
      mode: 'electron'
    }, map));
    (0, _expect["default"])({
      called: called,
      args: args
    }).to.eql({
      called: {
        onExternal: 0,
        onRedirect: 0,
        onSilentChange: 0,
        onUpdateRouter: 0
      },
      args: []
    });
  });
  it('should call onUpdateRouter callback if the path lead to chat', function () {
    var _callbacks2 = (0, _utils.callbacks)(),
        map = _callbacks2.map,
        called = _callbacks2.called,
        args = _callbacks2.args;

    (0, _["default"])('https://grape.io/chat', _objectSpread({
      currChannel: 6009,
      serviceUrl: 'https://grape.io',
      mode: 'electron'
    }, map));
    (0, _expect["default"])({
      called: called,
      args: args
    }).to.eql({
      called: {
        onExternal: 0,
        onRedirect: 0,
        onSilentChange: 0,
        onUpdateRouter: 1
      },
      args: ['/chat', 'push']
    });
  });
  it('should call onSilentChange callback if URL contains messageId and channel is current', function () {
    var _callbacks3 = (0, _utils.callbacks)(),
        map = _callbacks3.map,
        called = _callbacks3.called,
        args = _callbacks3.args;

    (0, _["default"])('https://grape.io/chat/channel/6009:3d062f7810d411e8aa120242ac1d0003', _objectSpread({
      currChannel: 6009,
      serviceUrl: 'https://grape.io',
      mode: 'electron'
    }, map));
    (0, _expect["default"])({
      called: called,
      args: args
    }).to.eql({
      called: {
        onExternal: 0,
        onRedirect: 0,
        onSilentChange: 1,
        onUpdateRouter: 0
      },
      args: ['/chat/channel/6009:3d062f7810d411e8aa120242ac1d0003', {
        channelId: 6009,
        messageId: '3d062f7810d411e8aa120242ac1d0003',
        type: 'channel'
      }]
    });
  });
  it('should call onUpdateRouter callback if URL has no messageId and channel is not current', function () {
    var _callbacks4 = (0, _utils.callbacks)(),
        map = _callbacks4.map,
        called = _callbacks4.called,
        args = _callbacks4.args;

    (0, _["default"])('https://grape.io/chat/channel/6009', _objectSpread({
      currChannel: 2000,
      serviceUrl: 'https://grape.io',
      mode: 'electron'
    }, map));
    (0, _expect["default"])({
      called: called,
      args: args
    }).to.eql({
      called: {
        onExternal: 0,
        onRedirect: 0,
        onSilentChange: 0,
        onUpdateRouter: 1
      },
      args: ['/chat/channel/6009', 'push']
    });
  });
  it('should call onUpdateRouter callback if URL contains messageId and channel is not current', function () {
    var _callbacks5 = (0, _utils.callbacks)(),
        map = _callbacks5.map,
        called = _callbacks5.called,
        args = _callbacks5.args;

    (0, _["default"])('https://grape.io/chat/channel/6009:3d062f7810d411e8aa120242ac1d0003', _objectSpread({
      currChannel: 2000,
      serviceUrl: 'https://grape.io',
      mode: 'electron'
    }, map));
    (0, _expect["default"])({
      called: called,
      args: args
    }).to.eql({
      called: {
        onExternal: 0,
        onRedirect: 0,
        onSilentChange: 0,
        onUpdateRouter: 1
      },
      args: ['/chat/channel/6009:3d062f7810d411e8aa120242ac1d0003', 'push']
    });
  });
  it('should call onExternal callback if URL leads to external website', function () {
    var _callbacks6 = (0, _utils.callbacks)(),
        map = _callbacks6.map,
        called = _callbacks6.called,
        args = _callbacks6.args;

    (0, _["default"])('https://github.com', _objectSpread({
      currChannel: 2000,
      serviceUrl: 'https://grape.io',
      mode: 'electron'
    }, map));
    (0, _expect["default"])({
      called: called,
      args: args
    }).to.eql({
      called: {
        onExternal: 1,
        onRedirect: 0,
        onSilentChange: 0,
        onUpdateRouter: 0
      },
      args: ['https://github.com', '_blank']
    });
  });
  it('should call onExternal callback if URL has a foreign domain but the path is /chat/channel/:channelId', function () {
    var _callbacks7 = (0, _utils.callbacks)(),
        map = _callbacks7.map,
        called = _callbacks7.called,
        args = _callbacks7.args;

    (0, _["default"])('https://github.com/chat/channel/6009', _objectSpread({
      currChannel: 2000,
      serviceUrl: 'https://grape.io',
      mode: 'electron'
    }, map));
    (0, _expect["default"])({
      called: called,
      args: args
    }).to.eql({
      called: {
        onExternal: 1,
        onRedirect: 0,
        onSilentChange: 0,
        onUpdateRouter: 0
      },
      args: ['https://github.com/chat/channel/6009', '_blank']
    });
  });
  it('should call onExternal callback if URL has a foreign domain but the path is /chat/pm/:mateId', function () {
    var _callbacks8 = (0, _utils.callbacks)(),
        map = _callbacks8.map,
        called = _callbacks8.called,
        args = _callbacks8.args;

    (0, _["default"])('https://github.com/chat/pm/200', _objectSpread({
      currChannel: 2000,
      serviceUrl: 'https://grape.io',
      mode: 'electron'
    }, map));
    (0, _expect["default"])({
      called: called,
      args: args
    }).to.eql({
      called: {
        onExternal: 1,
        onRedirect: 0,
        onSilentChange: 0,
        onUpdateRouter: 0
      },
      args: ['https://github.com/chat/pm/200', '_blank']
    });
  });
  it('should call onExternal callback if URL with query param leads to sso page', function () {
    var _callbacks9 = (0, _utils.callbacks)(),
        map = _callbacks9.map,
        called = _callbacks9.called,
        args = _callbacks9.args;

    (0, _["default"])('https://grape.io/sso/sso?next=/chat', _objectSpread({
      currChannel: 2000,
      serviceUrl: 'https://grape.io/sso/sso?next=/chat',
      mode: 'electron'
    }, map));
    (0, _expect["default"])({
      called: called,
      args: args
    }).to.eql({
      called: {
        onExternal: 1,
        onRedirect: 0,
        onSilentChange: 0,
        onUpdateRouter: 0
      },
      args: ['https://grape.io/sso/sso?next=/chat', '_blank']
    });
  });
  it('should call onRedirect callback if URL leads to login page', function () {
    var _callbacks10 = (0, _utils.callbacks)(),
        map = _callbacks10.map,
        called = _callbacks10.called,
        args = _callbacks10.args;

    (0, _["default"])('https://grape.io/accounts/login', _objectSpread({
      currChannel: 2000,
      serviceUrl: 'https://grape.io',
      mode: 'electron'
    }, map));
    (0, _expect["default"])({
      called: called,
      args: args
    }).to.eql({
      called: {
        onExternal: 0,
        onRedirect: 1,
        onSilentChange: 0,
        onUpdateRouter: 0
      },
      args: ['https://grape.io/accounts/login']
    });
  });
  it('should call onRedirect callback if URL leads to logout page', function () {
    var _callbacks11 = (0, _utils.callbacks)(),
        map = _callbacks11.map,
        called = _callbacks11.called,
        args = _callbacks11.args;

    (0, _["default"])('https://grape.io/accounts/logout', _objectSpread({
      currChannel: 2000,
      serviceUrl: 'https://grape.io',
      mode: 'electron'
    }, map));
    (0, _expect["default"])({
      called: called,
      args: args
    }).to.eql({
      called: {
        onExternal: 0,
        onRedirect: 1,
        onSilentChange: 0,
        onUpdateRouter: 0
      },
      args: ['https://grape.io/accounts/logout']
    });
  });
  it('should call onExternal callback if URL outside of the chat', function () {
    var _callbacks12 = (0, _utils.callbacks)(),
        map = _callbacks12.map,
        called = _callbacks12.called,
        args = _callbacks12.args;

    (0, _["default"])('https://grape.io/accounts/xxx', _objectSpread({
      currChannel: 2000,
      serviceUrl: 'https://grape.io',
      mode: 'electron'
    }, map));
    (0, _expect["default"])({
      called: called,
      args: args
    }).to.eql({
      called: {
        onExternal: 1,
        onRedirect: 0,
        onSilentChange: 0,
        onUpdateRouter: 0
      },
      args: ['https://grape.io/accounts/xxx', 'grape']
    });
  });
  it('should call onExternal callback if the path have parameters', function () {
    var _callbacks13 = (0, _utils.callbacks)(),
        map = _callbacks13.map,
        called = _callbacks13.called,
        args = _callbacks13.args;

    (0, _["default"])('https://grape.io/guests/invite/?group_id=5&next=/chat', _objectSpread({
      currChannel: 2000,
      serviceUrl: 'https://grape.io',
      mode: 'electron'
    }, map));
    (0, _expect["default"])({
      called: called,
      args: args
    }).to.eql({
      called: {
        onExternal: 1,
        onRedirect: 0,
        onSilentChange: 0,
        onUpdateRouter: 0
      },
      args: ['https://grape.io/guests/invite/?group_id=5&next=/chat', 'grape']
    });
  });
  it('should call onExternal callback if URL leads to the root', function () {
    var _callbacks14 = (0, _utils.callbacks)(),
        map = _callbacks14.map,
        called = _callbacks14.called,
        args = _callbacks14.args;

    (0, _["default"])('https://grape.io/', _objectSpread({
      currChannel: 2000,
      serviceUrl: 'https://grape.io',
      mode: 'electron'
    }, map));
    (0, _expect["default"])({
      called: called,
      args: args
    }).to.eql({
      called: {
        onExternal: 0,
        onRedirect: 1,
        onSilentChange: 0,
        onUpdateRouter: 0
      },
      args: ['https://grape.io/']
    });
  });
});